@testset "read" begin
    file = pkgdir(SellmeierFit, "example", "data", "Malitson.csv")

    d0 = SellmeierFit.read(file)
    d1 = SellmeierFit.read(file, unit_prefix=1.0)
    @test (d0.λ == micro .* d1.λ) && d0.ε==d1.ε

    d2 = SellmeierFit.read(file, unit_prefix=1.0, s_col=2, n_col=1)
    @test (d2.λ .^2 == sort(d1.ε)) && (sort(d2.ε) == d1.λ .^ 2)

    d3 = SellmeierFit.read(file, s_var=FREQUENCY)
    @test (d3.λ == reverse(c₀ ./ d0.λ)) && (d3.ε == reverse(d0.ε))

    d4 = SellmeierFit.read(file, s_var=ENERGY)
    @test (d4.λ == reverse(ℎc₀ ./ d0.λ)) && (d4.ε == reverse(d0.ε))

    material = "SiO2"
    author = "Malitson"
    filepath = joinpath(SellmeierFit.DIR_RI_INFO, material, author * ".csv")
    file_exists = isfile(filepath)
    file_exists && rm(filepath)
    try
        d = SellmeierFit.read(RefractiveIndexInfo(material, author, force_download=true))  # file doesn't exist; download is performed
        @test d == d0

        d = SellmeierFit.read(RefractiveIndexInfo(material, author))  # file already exists; download is not performed
        @test d == d0
    catch e
        @test e isa Downloads.RequestError
    finally
        !file_exists && rm(filepath)
    end

    author = "Abc"  # fake author name
    filepath = joinpath(SellmeierFit.DIR_RI_INFO, material, author * ".csv")
    @test_throws RequestError SellmeierFit.read(RefractiveIndexInfo(material, author, force_download=true))

    material = "Si"
    author = "Aspnes"
    filepath = joinpath(SellmeierFit.DIR_RI_INFO, material, author * ".csv")
    file_exists = isfile(filepath)

    d_n = SellmeierFit.read(RefractiveIndexInfo(material, author))  # n_tbl = 1
    d_k = SellmeierFit.read(RefractiveIndexInfo(material, author), n_tbl=2)

    @test d_n.λ == d_k.λ
    @test d_n.ε ≠ d_k.ε

    !file_exists && rm(filepath)
end  # @testset "read"
